==> vue-skeleton-item-2.22.1.tgz: package/lib/mobile-first.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/skeleton-item/vue';
import { defineComponent, props, setup } from '@opentinyvue/vue-common';
import { iconPicture } from '@opentinyvue/vue-icon';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var classes = {
  // 骨架屏形态
  "shape-image": "flex justify-center items-center",
  "shape-circle": "rounded-full",
  "shape-square": "w-full h-10 mb-3",
  // 图片尺寸
  "image-small": "w-6 h-6",
  "image-medium": "w-7 h-7",
  "image-large": "w-8 h-8",
  // 圆角尺寸
  "circle-small": "w-6 h-6",
  "circle-medium": "w-7 h-7",
  "circle-large": "w-8 h-8"
};
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    class: _vm.m("bg-color-fill-3", _vm.variant === "image" && "fill-color-border", _vm.variant !== "circle" && "rounded", _vm.gcls("shape-" + _vm.variant), _vm.variant !== "square" ? _vm.gcls(_vm.variant + "-" + _vm.size) : "", _vm.state.isActive && "bg-200-100 bg-gradient-to-r from-color-border-separator via-color-bg-2 to-color-border-separator animate-skeleton-loading-1500ms"),
    attrs: {
      "data-tag": "tiny-skeleton-item"
    }
  }, [_vm.variant === "image" ? _vm._t("default", function() {
    return [_c("icon-picture", {
      staticClass: "w-3/5 h-3/5"
    })];
  }) : _vm._e()], 2);
};
var staticRenderFns = [];
var __vue2_script = defineComponent({
  props: [].concat(props, ["variant", "size"]),
  components: {
    IconPicture: iconPicture()
  },
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api,
      classes
    });
  }
});
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobileFirst = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { mobileFirst as default };

==> vue-skeleton-item-2.23.0.tgz: package/lib/mobile-first.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/skeleton-item/vue';
import { defineComponent, props, setup } from '@opentinyvue/vue-common';
import { iconPicture } from '@opentinyvue/vue-icon';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var classes = {
  // 骨架屏形态
  "shape-image": "flex justify-center items-center",
  "shape-circle": "rounded-full",
  "shape-square": "w-full h-10 mb-3",
  // 图片尺寸
  "image-small": "w-6 h-6",
  "image-medium": "w-7 h-7",
  "image-large": "w-8 h-8",
  // 圆角尺寸
  "circle-small": "w-6 h-6",
  "circle-medium": "w-7 h-7",
  "circle-large": "w-8 h-8"
};
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    class: _vm.m("bg-color-fill-3", _vm.variant === "image" && "fill-color-border", _vm.variant !== "circle" && "rounded", _vm.gcls("shape-" + _vm.variant), _vm.variant !== "square" ? _vm.gcls(_vm.variant + "-" + _vm.size) : "", _vm.state.isActive && "bg-w200h100 bg-gradient-to-r from-color-border-separator via-color-bg-2 to-color-border-separator animate-skeleton-loading-1500ms"),
    attrs: {
      "data-tag": "tiny-skeleton-item"
    }
  }, [_vm.variant === "image" ? _vm._t("default", function() {
    return [_c("icon-picture", {
      staticClass: "w-3/5 h-3/5"
    })];
  }) : _vm._e()], 2);
};
var staticRenderFns = [];
var __vue2_script = defineComponent({
  props: [].concat(props, ["variant", "size"]),
  components: {
    IconPicture: iconPicture()
  },
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api,
      classes
    });
  }
});
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobileFirst = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { mobileFirst as default };
